@@ -51,6 +51,18 @@ def getOrEmptyString(dic, key, default=''):
         return default
     return val
 
+
+def getUpdatedPipelineHistoryStr(pipeline_id, existing_pipeline_history):
+    new_pipeline_history = ''
+    if existing_pipeline_history == '':
+        new_pipeline_history = pipeline_id
+    else:
+        if pipeline_id in existing_pipeline_history:
+            new_pipeline_history = existing_pipeline_history
+        else:
+            new_pipeline_history = existing_pipeline_history + "," + pipeline_id
+    return new_pipeline_history
+
 class S3FileobjUploader:
     def __init__(self, s3, fileobj, params, options={'disable_gzip': False}):
         self.s3 = s3
@@ -210,6 +222,8 @@ class Datalake:
         file_key = os.path.join(org_slug, source_id, file_category, raw_file_path, file_name)
         file_id = str(uuid4())
         pipelineConfig = context.get('pipelineConfig', {})
+        pipeline_history_str = getUpdatedPipelineHistoryStr(getOrEmptyString(context, 'pipelineId'),
+                                                            getOrEmptyString(file_meta, FIELDS['PIPELINE_HISTORY']))
         meta = {
             # constant
             FIELDS['INTEGRATION_TYPE']: 'datapipeline',
@@ -242,7 +256,8 @@ class Datalake:
             FIELDS['PIPELINE_MASTER_SCRIPT']: f"{context.get('masterScriptNamespace', '')}/{context.get('masterScriptSlug', '')}:{context.get('masterScriptVersion', '')}",
             FIELDS['PIPELINE_TASK_EXECUTION_ID']: getOrEmptyString(context, 'taskId'),
             FIELDS['PIPELINE_TASK_SCRIPT']: getOrEmptyString(context, 'taskScript'),
-            FIELDS['PIPELINE_TASK_SLUG']: getOrEmptyString(context, 'taskSlug')
+            FIELDS['PIPELINE_TASK_SLUG']: getOrEmptyString(context, 'taskSlug'),
+            FIELDS['PIPELINE_HISTORY']: pipeline_history_str
         }
 
         params = {
@@ -364,6 +379,9 @@ class Datalake:
 
         pipelineConfig = context.get('pipelineConfig', {})
 
+        pipeline_history_str = getUpdatedPipelineHistoryStr(getOrEmptyString(context, 'pipelineId'),
+                                                            getOrEmptyString(current_meta, FIELDS['PIPELINE_HISTORY']))
+
         params = {
             'Bucket': bucket,
             'CopySource': f'/{bucket}/{file_key}',
@@ -390,7 +408,8 @@ class Datalake:
                 FIELDS['PIPELINE_MASTER_SCRIPT']: f"{context.get('masterScriptNamespace', '')}/{context.get('masterScriptSlug', '')}:{context.get('masterScriptVersion', '')}",
                 FIELDS['PIPELINE_TASK_EXECUTION_ID']: getOrEmptyString(context, 'taskId'),
                 FIELDS['PIPELINE_TASK_SCRIPT']: getOrEmptyString(context, 'taskScript'),
-                FIELDS['PIPELINE_TASK_SLUG']: getOrEmptyString(context, 'taskSlug')
+                FIELDS['PIPELINE_TASK_SLUG']: getOrEmptyString(context, 'taskSlug'),
+                FIELDS['PIPELINE_HISTORY']: pipeline_history_str
             },
             'MetadataDirective': 'REPLACE',
             'ServerSideEncryption': 'aws:kms',
